@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from cltoolbox import arg, command, main
 
 
@@ -8,8 +9,8 @@ def ex(foo, b=None, spam=None):
 
     :param foo: Bla bla.
     :param b: A little flag.
-    :param spam: Spam spam spam spam."""
-
+    :param spam: Spam spam spam spam.
+    """
     print((foo, b, spam))
 
 
